package com.cloud9.pdcjavaapp;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.widget.TextView;

import com.cloud9.sdk.pdc;
import com.cloud9.sdk.iPDCManager;
import com.cloud9.sdk.iPDCManagerNotify;

import org.json.JSONException;
import org.json.JSONObject;

public class MainActivity extends Activity {
    static class PDCNotification extends iPDCManagerNotify
    {
        private MainActivity activity_;
        public void setActivity(MainActivity activity) { activity_ = activity; }

        private class TransactionFinishedRunnable implements Runnable
        {
            private MainActivity activity_;
            private String jsonResponse_;
            public TransactionFinishedRunnable(MainActivity activity, String jsonResponse) {
                activity_ = activity;
                jsonResponse_ = jsonResponse;
            }
            @Override
            public void run() {
                JSONObject obj = null;
                String responseMessage = "";
                try {
                    obj = new JSONObject(jsonResponse_);
                    responseMessage = obj.getString("ResponseText");
                } catch (JSONException e) {
                    e.printStackTrace();
                }
                activity_.transaction_finished(responseMessage);
            }
        }
        private class TransactionErrorRunnable implements Runnable
        {
            private MainActivity activity_;
            private int errorCode_;
            private String jsonResponse_;
            public TransactionErrorRunnable(MainActivity activity, int errorCode, String jsonResponse) {
                activity_ = activity;
                errorCode_ = errorCode;
                jsonResponse_ = jsonResponse;
            }
            @Override
            public void run() {
                JSONObject obj = null;
                String errorMessage = "";
                try {
                    obj = new JSONObject(jsonResponse_);
                    errorMessage = obj.getString("ErrorText");
                } catch (JSONException e) {
                    e.printStackTrace();
                }
                activity_.transaction_error(errorCode_, errorMessage);
            }
        }
        // We post here the C++ callback to the Android UI thread, using a runnable
        public void HttpsDataReceivedCallback(String jsonResponse) {
            activity_.runOnUiThread(new TransactionFinishedRunnable(activity_, jsonResponse));
        }
        public void HttpsErrorOccurredCallback(int errorCode, String jsonResponse) {
            activity_.runOnUiThread(new TransactionErrorRunnable(activity_, errorCode, jsonResponse));
        }
        public void ICMErrorOccurredCallback(int errorCode, String jsonResponse) {
            activity_.runOnUiThread(new TransactionErrorRunnable(activity_, errorCode, jsonResponse));
        }
    }

    public void transaction_finished(String jsonResponse) {
        System.out.print("Transaction finished. Json response: " + jsonResponse);
        TextView tv = findViewById(R.id.sample_text);
        tv.setText("Transaction finished");
    }

    public void transaction_error(int errorCode, String errorMessage) {
        TextView tv = findViewById(R.id.sample_text);
        tv.setText("Transaction error: " + errorMessage);
    }

    static iPDCManager manager_;
    static PDCNotification notification_;

    public static iPDCManager getPDCManagerInstance() {
        if (manager_ == null) {
            manager_ = pdc.createPDCManager();
            manager_.initWithDelegate(getPDCNotificationInstance());
        }
        return manager_;
    }
    public static PDCNotification getPDCNotificationInstance() {
        if (notification_ == null) {
            notification_ = new PDCNotification();
        }
        return notification_;
    }

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        Intent intent = new Intent(this, com.cloud9.sdk.ActivityLoadSdk.class);
        this.startActivityForResult(intent, 0);
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        super.onActivityResult(requestCode, resultCode, data);

        getPDCNotificationInstance().setActivity(this);
    }

    public void onSaleButtonClick(View view) {
        TextView tv = findViewById(R.id.sample_text);
        tv.setText("Transaction in progress...");
        String jsonRequest = "{\"ExtraChargeAmt\":\"0\",\"GMID\":\"1001396340\",\"GMPW\":\"01\"," +
                "\"GTID\":\"GT1001396499\",\"IncCashBackAmt\":\"0\",\"IncTaxAmt\":\"0\"," +
                "\"MainAmt\":\"1000\",\"Medium\":\"Credit\",\"NeedSwipCard\":\"Y\"," +
                "\"TipAmt\":\"0\",\"TransType\":\"Sale\"}";
        getPDCManagerInstance().postTransactionToUrl("https://testlink.c9pg.com:11911/restApi", jsonRequest);
    }
}
